#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
key:                  lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  14ff3acbd03391725e05c8b7fad7085d
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.7-8DwTpSJG0WR4WGLDokvZMp
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lens-aeson-1.2.3-9vzGEq3SnHm1ppljJ0sdqo
    lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4 mtl-2.3.1
    prettyprinter-1.7.2-1DGqCnBpxP9HlPCcGuqpc1
    random-1.2.1.3-2fto0SX8B0n5d0nC1pFLHo
    row-types-1.0.1.2-DPodS6wEnzgipmVs1yqhU
    sorted-list-0.2.3.1-HWlvtQShLGJE6VWzHzO4ni stm-2.5.1.0
    temporary-1.3-6srFELH6ZJ85EWwSBp1olQ text-2.0.2
    text-rope-0.3-Ei55WDCsuAqIC7ggXqwhlE transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    uuid-1.3.16.1-8Wpd3om6bCL87vO2yxvkz8

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

